@@ -1924,7 +1924,7 @@ class TestTaxView(ModelView, TaxableMixin):
         pool = Pool()
         Company = pool.get('company.company')
         company_id = Transaction().context.get('company')
-        if company_id:
+        if company_id is not None and company_id >= 0:
             company = Company(company_id)
             return company.currency.id
 
@@ -1933,7 +1933,7 @@ class TestTaxView(ModelView, TaxableMixin):
         pool = Pool()
         Company = pool.get('company.company')
         company_id = Transaction().context.get('company')
-        if company_id:
+        if company_id is not None and company_id >= 0:
             return Company(company_id)
 
     @property
